@@ -30,6 +30,7 @@ from twisted.internet import error, defer, interfaces, protocol
 from twisted.python import log, failure
 from twisted.names import (
     dns, common, resolve, cache, root, hosts as hostsModule)
+from twisted.internet.abstract import isIPv6Address
 
 
 
@@ -72,7 +73,7 @@ class Resolver(common.ResolverBase):
         round-robin fashion.  If given, C{resolv} is periodically checked
         for modification and re-parsed if it is noticed to have changed.
 
-        @type servers: C{list} of C{(str, int)} or C{None}
+        @type servers: C{list} of C{(str, int)} or L{None}
         @param servers: If not None, interpreted as a list of (host, port)
             pairs specifying addresses of domain name servers to attempt to use
             for this lookup.  Host addresses should be in IPv4 dotted-quad
@@ -157,12 +158,12 @@ class Resolver(common.ResolverBase):
             else:
                 raise
         else:
-            mtime = os.fstat(resolvConf.fileno()).st_mtime
-            if mtime != self._lastResolvTime:
-                log.msg('%s changed, reparsing' % (self.resolv,))
-                self._lastResolvTime = mtime
-                self.parseConfig(resolvConf)
-            resolvConf.close()
+            with resolvConf:
+                mtime = os.fstat(resolvConf.fileno()).st_mtime
+                if mtime != self._lastResolvTime:
+                    log.msg('%s changed, reparsing' % (self.resolv,))
+                    self._lastResolvTime = mtime
+                    self.parseConfig(resolvConf)
 
         # Check again in a little while
         self._parseCall = self._reactor.callLater(
@@ -211,7 +212,7 @@ class Resolver(common.ResolverBase):
             return self.dynServers[self.index - serverL]
 
 
-    def _connectedProtocol(self):
+    def _connectedProtocol(self, interface=''):
         """
         Return a new L{DNSDatagramProtocol} bound to a randomly selected port
         number.
@@ -219,7 +220,8 @@ class Resolver(common.ResolverBase):
         proto = dns.DNSDatagramProtocol(self, reactor=self._reactor)
         while True:
             try:
-                self._reactor.listenUDP(dns.randomSource(), proto)
+                self._reactor.listenUDP(dns.randomSource(), proto,
+                                        interface=interface)
             except error.CannotListenError:
                 pass
             else:
@@ -260,7 +262,10 @@ class Resolver(common.ResolverBase):
         @return: A L{Deferred} which will be called back with the result of the
             query.
         """
-        protocol = self._connectedProtocol()
+        if isIPv6Address(args[0][0]):
+            protocol = self._connectedProtocol(interface='::')
+        else:
+            protocol = self._connectedProtocol()
         d = protocol.query(*args)
         def cbQueried(result):
             protocol.transport.stopListening()
@@ -362,8 +367,8 @@ class Resolver(common.ResolverBase):
         If the message was truncated, re-attempt the query over TCP and return
         a Deferred which will fire with the results of that query.
 
-        If the message's result code is not L{dns.OK}, return a Failure
-        indicating the type of error which occurred.
+        If the message's result code is not C{twisted.names.dns.OK}, return a
+        Failure indicating the type of error which occurred.
 
         Otherwise, return a three-tuple of lists containing the results from
         the answers section, the authority section, and the additional section.
@@ -548,19 +553,19 @@ def createResolver(servers=None, resolvconf=None, hosts=None):
     """
     Create and return a Resolver.
 
-    @type servers: C{list} of C{(str, int)} or C{None}
+    @type servers: C{list} of C{(str, int)} or L{None}
 
-    @param servers: If not C{None}, interpreted as a list of domain name servers
+    @param servers: If not L{None}, interpreted as a list of domain name servers
     to attempt to use. Each server is a tuple of address in C{str} dotted-quad
     form and C{int} port number.
 
-    @type resolvconf: C{str} or C{None}
-    @param resolvconf: If not C{None}, on posix systems will be interpreted as
+    @type resolvconf: C{str} or L{None}
+    @param resolvconf: If not L{None}, on posix systems will be interpreted as
     an alternate resolv.conf to use. Will do nothing on windows systems. If
-    C{None}, /etc/resolv.conf will be used.
+    L{None}, /etc/resolv.conf will be used.
 
-    @type hosts: C{str} or C{None}
-    @param hosts: If not C{None}, an alternate hosts file to use. If C{None}
+    @type hosts: C{str} or L{None}
+    @param hosts: If not L{None}, an alternate hosts file to use. If L{None}
     on posix systems, /etc/hosts will be used. On windows, C:\windows\hosts
     will be used.
 
@@ -591,7 +596,7 @@ def getResolver():
     """
     Get a Resolver instance.
 
-    Create twisted.names.client.theResolver if it is C{None}, and then return
+    Create twisted.names.client.theResolver if it is L{None}, and then return
     that value.
 
     @rtype: C{IResolver}
