@@ -7,9 +7,9 @@ Test cases for twisted.names.
 
 from __future__ import absolute_import, division
 
-import socket
-import operator
 import copy
+import operator
+import socket
 
 from io import BytesIO
 from functools import partial, reduce
@@ -25,8 +25,11 @@ from twisted.names.error import DomainError
 from twisted.names.client import Resolver
 from twisted.names.secondary import (
     SecondaryAuthorityService, SecondaryAuthority)
+from twisted.python.compat import nativeString
+from twisted.python.filepath import FilePath
 
-from twisted.test.proto_helpers import StringTransport, MemoryReactorClock
+from twisted.test.proto_helpers import (
+    StringTransport, MemoryReactorClock, waitUntilAllDisconnected)
 
 def justPayload(results):
     return [r.payload for r in results[0]]
@@ -196,6 +199,8 @@ class ServerDNSTests(unittest.TestCase):
         for conn in self.factory.connections[:]:
             conn.transport.loseConnection()
 
+        return waitUntilAllDisconnected(reactor, self.factory.connections[:])
+
 
     def namesTest(self, querying, expectedRecords):
         """
@@ -525,8 +530,7 @@ class ResolvConfHandlingTests(unittest.TestCase):
 
     def test_empty(self):
         resolvConf = self.mktemp()
-        fObj = open(resolvConf, 'w')
-        fObj.close()
+        open(resolvConf, 'w').close()
         r = client.Resolver(resolv=resolvConf)
         self.assertEqual(r.dynServers, [('127.0.0.1', 53)])
         r._parseCall.cancel()
@@ -1036,3 +1040,161 @@ class SecondaryAuthorityTests(unittest.TestCase):
         result = self.successResultOf(secondary.lookupAddress('example.com'))
         self.assertEqual((
                 [RRHeader(b'example.com', payload=a, auth=True)], [], []), result)
+
+
+
+sampleBindZone = b"""\
+$ORIGIN example.com.
+$TTL    1w
+example.com. IN SOA dns.example.com (
+            2013120201 ; serial number of this zone file
+            1d         ; slave refresh
+            2h         ; slave retry time in case of a problem
+            4w         ; slave expiration time
+            1h         ; maximum caching time in case of failed lookups
+            )
+
+; A comment.
+@                  IN AAAA 2001:db8:10::1
+example.com.       IN A 10.0.0.1
+no-in.example.com. A 10.0.0.2  ; technically wrong but used to work
+not-fqdn           IN MX 10 mx.example.com
+www                IN CNAME example.com"""
+
+
+
+class BindAuthorityTests(unittest.TestCase):
+    """
+    Tests for L{twisted.names.authority.BindAuthority}.
+    """
+    def loadBindString(self, s):
+        """
+        Create a new L{twisted.names.authority.BindAuthority} from C{s}.
+
+        @param s: A string with BIND zone data.
+        @type s: bytes
+
+        @return: a new bind authority
+        @rtype: L{twisted.names.authority.BindAuthority}
+        """
+        fp = FilePath(self.mktemp().encode("ascii"))
+        fp.setContent(s)
+
+        return authority.BindAuthority(fp.path)
+
+
+    def setUp(self):
+        self.auth = self.loadBindString(sampleBindZone)
+
+
+    def test_ttl(self):
+        """
+        Loads the default $TTL and applies it to all records.
+        """
+        for dom in self.auth.records.keys():
+            for rec in self.auth.records[dom]:
+                self.assertTrue(
+                    604800 == rec.ttl
+                )
+
+
+    def test_originFromFile(self):
+        """
+        Loads the default $ORIGIN.
+        """
+        self.assertEqual(
+            b"example.com.", self.auth.origin,
+        )
+        self.assertIn(
+            b"not-fqdn.example.com", self.auth.records,
+        )
+
+
+    def test_aRecords(self):
+        """
+        A records are loaded.
+        """
+        for dom, ip in [(b"example.com", u"10.0.0.1"),
+                        (b"no-in.example.com", u"10.0.0.2")]:
+            rr = self.successResultOf(
+                self.auth.lookupAddress(dom)
+            )[0][0]
+            self.assertEqual(
+                dns.Record_A(
+                    ip,
+                    604800,
+                ),
+                rr.payload,
+            )
+
+
+    def test_aaaaRecords(self):
+        """
+        AAAA records are loaded.
+        """
+        rr = self.successResultOf(
+            self.auth.lookupIPV6Address(b"example.com")
+        )[0][0]
+        self.assertEqual(
+            dns.Record_AAAA(
+                u"2001:db8:10::1",
+                604800,
+            ),
+            rr.payload,
+        )
+
+
+    def test_mxRecords(self):
+        """
+        MX records are loaded.
+        """
+        rr = self.successResultOf(
+            self.auth.lookupMailExchange(b"not-fqdn.example.com")
+        )[0][0]
+        self.assertEqual(
+            dns.Record_MX(
+                preference=10, name="mx.example.com", ttl=604800,
+            ),
+            rr.payload,
+        )
+
+
+    def test_cnameRecords(self):
+        """
+        CNAME records are loaded.
+        """
+        rr = self.successResultOf(
+            self.auth.lookupIPV6Address(b"www.example.com")
+        )[0][0]
+        self.assertEqual(
+            dns.Record_CNAME(
+                name="example.com", ttl=604800,
+            ),
+            rr.payload,
+        )
+
+
+    def test_invalidRecordClass(self):
+        """
+        loadBindString raises NotImplementedError on invalid records.
+        """
+        with self.assertRaises(NotImplementedError) as e:
+            self.loadBindString(
+                b"example.com. IN LOL 192.168.0.1"
+            )
+        self.assertEqual(
+            "Record type 'LOL' not supported", e.exception.args[0]
+        )
+
+
+    def test_invalidDirectives(self):
+        """
+        $INCLUDE and $GENERATE raise NotImplementedError.
+        """
+        for directive in (b"$INCLUDE", b"$GENERATE"):
+            with self.assertRaises(NotImplementedError) as e:
+                self.loadBindString(directive + b" doesNotMatter")
+            self.assertEqual(
+                nativeString(directive + b" directive not implemented"),
+                e.exception.args[0]
+            )
