@@ -778,7 +778,7 @@ class TLSMemoryBIOTests(TestCase):
 
         # And when the connection completely dies, check the reason.
         def cbDisconnected(clientProtocol):
-            clientProtocol.lostConnectionReason.trap(Error)
+            clientProtocol.lostConnectionReason.trap(Error, ConnectionLost)
         clientConnectionLost.addCallback(cbDisconnected)
         return clientConnectionLost
 
@@ -1379,7 +1379,8 @@ class TLSProducerTests(TestCase):
         producer is not used, and its stopProducing method is called.
         """
         clientProtocol, tlsProtocol = buildTLSProtocol()
-        clientProtocol.connectionLost = lambda reason: reason.trap(Error)
+        clientProtocol.connectionLost = lambda reason: reason.trap(
+            Error, ConnectionLost)
 
         class Producer(object):
             stopped = False
